# GrammarCorrector

GrammarCorrector is a Python package that uses a remote model hosted on Replicate to correct grammatical errors in text.

## Installation

```bash
pip install grammarcorrector
```

## Usage

```bash
export REPLICATE_API_TOKEN='your_replicate_api_token'
```

```python
from grammarcorrector import GrammarCorrector

corrector = GrammarCorrector()
corrected_text = corrector.correct("This are bad grammar sentence.")
print(corrected_text)  # Output: "This is a bad grammar sentence."
```
